﻿Imports System.Runtime.InteropServices
Public Class UserControl1
    Inherits Form

    ' Win32 APIのインポート
    <DllImport("USER32.DLL")> _
    Private Shared Function GetSystemMenu(ByVal hWnd As IntPtr, ByVal bRevert As Integer) As IntPtr
    End Function
    <DllImport("USER32.DLL")> _
    Private Shared Function RemoveMenu(ByVal hMenu As IntPtr, ByVal nPosition As Integer, ByVal wFlags As Integer) As Integer
    End Function

    ' ［閉じる］ボタンを無効化するための値
    Private Shared SC_CLOSE As Integer = &HF060
    Private Shared MF_BYCOMMAND As Integer = &H0

    ' コンストラクタ（初期化処理などを呼び出す）
    Public Sub New()
        MyBase.New()

        ' 初期化処理
        InitializeComponent()

        ' コントロールボックスの［閉じる］ボタンの無効化
        Dim hMenu As IntPtr = GetSystemMenu(Me.Handle, 0)
        RemoveMenu(hMenu, SC_CLOSE, MF_BYCOMMAND)

    End Sub

    Private Declare Function SendMessage Lib "User32.dll" Alias "SendMessageA" (ByVal hWnd As IntPtr, ByVal wMsg As Integer, ByVal wParam As Integer, ByVal lParam As Integer) As Long
    Private Declare Sub ReleaseCapture Lib "User32.dll" ()

    Const WM_NCLBUTTONDOWN = &HA1
    Const HTCAPTION = 2

    'Formダブルクリックで非表示にする
    Private Sub UserControl1_DoubleClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.DoubleClick
        Me.Visible = False
        Form1.ツールバーToolStripMenuItem.Checked = Me.Visible
    End Sub

    'Formをドラックで動かせるようにする
    Private Sub Form1_MouseMove(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseMove
        Try

            If e.Button = MouseButtons.Left Then
                Call ReleaseCapture()
                Call SendMessage(Me.Handle, WM_NCLBUTTONDOWN, HTCAPTION, 0&)
            End If
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCMouseMove:" & ex.Message)
        End Try

    End Sub

    '縮小ボタンクリック
    Private Sub Button2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button2.Click
        Try
            'プレビューの縮小
            If Form1.PrintPreviewControl1.Zoom > 0.2 Then
                Form1.PrintPreviewControl1.Zoom -= 0.1
            End If
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCZoomOut:" & ex.Message)
        End Try
    End Sub

    '拡大ボタンクリック
    Private Sub Button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button1.Click
        Try
            'プレビューの拡大
            Form1.PrintPreviewControl1.Zoom += 0.1
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCZoomUp:" & ex.Message)
        End Try
    End Sub

    '線の太さの変更
    Friend Sub NumericUpDown1_ValueChanged(ByVal sender As System.Object, ByVal e As System.EventArgs)
        Try
            Dim UserCont2 As UserControl2 = Form1.SplitContainer1.Panel2.Controls("UserControl2")
            '線の太さ反映
            Form1.PenWidth = NumUpDown_PenWid.Value
            UserCont2.NumUpDown_PenWid.Value = NumUpDown_PenWid.Value
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCPenWidthChange:" & ex.Message)
        End Try
    End Sub

    '線の色の変更ボタンクリック
    Private Sub Button3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button3.Click
        Try
            'カラーダイアログの表示
            If ColorDialog1.ShowDialog <> Windows.Forms.DialogResult.Cancel Then
                'ペンの色の反映
                Panel_PenColor.BackColor = ColorDialog1.Color
                Form1.PenColor = ColorDialog1.Color
                Form1.Panel1.BackColor = ColorDialog1.Color
            End If

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCColorDialog:" & ex.Message)
        End Try
    End Sub

    'タイトルを付けるのチェック変更
    Private Sub CheckBox1_CheckedChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles CheckBox1.CheckedChanged
        Try
            'タイトル入力用テキストボックス使用可に
            TextBox1.Enabled = CheckBox1.Checked
            Form1.TitleBool = CheckBox1.Checked
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCTitleCheckChange:" & ex.Message)
        End Try
    End Sub

    '印刷するページ数の変更
    Private Sub NumericUpDown2_ValueChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles NumUpDown_PrintPage.ValueChanged
        Try
            '印刷するページ数を反映
            Form1.PrintPages = NumUpDown_PrintPage.Value
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCPrintPageChange:" & ex.Message)
        End Try
    End Sub

    '印刷用紙向きの変更
    Private Sub ComBox_PrintVectol_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ComBox_PrintVectol.SelectedIndexChanged
        Try
            Select Case ComBox_PrintVectol.SelectedItem
                Case "縦"
                    Form1.PrintVectol = Form1.PrintVectolENum.縦
                    If Form1.PrintType = Form1.PrintTypeENum.原稿用紙200字 Or Form1.PrintType = Form1.PrintTypeENum.原稿用紙400字 Then
                        Dim UserCont3 As UserControl3 = Form1.SplitContainer1.Panel2.Controls("UserControl3")
                        If Form1.PrintType = Form1.PrintTypeENum.原稿用紙200字 Then
                            UserCont3.NumUpDown_Gyo.Value = 20
                            UserCont3.NumUpDown_Retsu.Value = 10
                        Else
                            UserCont3.NumUpDown_Gyo.Value = 20
                            UserCont3.NumUpDown_Retsu.Value = 20
                        End If
                    End If
                Case "横"
                    Form1.PrintVectol = Form1.PrintVectolENum.横
                    If Form1.PrintType = Form1.PrintTypeENum.原稿用紙200字 Or Form1.PrintType = Form1.PrintTypeENum.原稿用紙400字 Then
                        Dim UserCont3 As UserControl3 = Form1.SplitContainer1.Panel2.Controls("UserControl3")
                        If Form1.PrintType = Form1.PrintTypeENum.原稿用紙200字 Then
                            UserCont3.NumUpDown_Gyo.Value = 10
                            UserCont3.NumUpDown_Retsu.Value = 20
                        Else
                            UserCont3.NumUpDown_Gyo.Value = 20
                            UserCont3.NumUpDown_Retsu.Value = 20
                        End If
                    End If
                Case Else
                    MsgBox("エラー！")
            End Select

            Select Case Form1.PrintVectol
                Case Form1.PrintVectolENum.縦
                    '印刷用紙向きを縦にセット
                    Form1.PrintDocument1.DefaultPageSettings.Landscape = False
                Case Form1.PrintVectolENum.横
                    '印刷用紙向きを横にセット
                    Form1.PrintDocument1.DefaultPageSettings.Landscape = True
            End Select

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCVecChange:" & ex.Message)
        End Try
    End Sub

    '用紙サイズの変更
    Private Sub ComBox_PrintSize_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ComBox_PrintSize.SelectedIndexChanged
        Try
            '用紙サイズの反映
            Form1.PrintDocument1.DefaultPageSettings.PaperSize = _
                Form1.PrintDocument1.PrinterSettings.PaperSizes(ComBox_PrintSize.SelectedIndex)

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCPrintSize:" & ex.Message)
        End Try
    End Sub

    '種類の変更
    Private Sub ListBox1_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ListBox1.SelectedIndexChanged
        Try
            Select Case ListBox1.SelectedItem
                Case "3mm方眼紙"
                    Form1.PrintType = Form1.PrintTypeENum.方眼紙3mm
                    Form1.PrintScale = 3
                Case "5mm方眼紙"
                    Form1.PrintType = Form1.PrintTypeENum.方眼紙5mm
                    Form1.PrintScale = 5
                Case "1cm方眼紙"
                    Form1.PrintType = Form1.PrintTypeENum.方眼紙10mm
                    Form1.PrintScale = 10
                Case "1.5cm方眼紙"
                    Form1.PrintType = Form1.PrintTypeENum.方眼紙15mm
                    Form1.PrintScale = 15
                Case "3mmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙3mm
                    Form1.PrintScale = 3
                Case "5mmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙5mm
                    Form1.PrintScale = 5
                Case "6mmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙6mm
                    Form1.PrintScale = 6
                Case "7mmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙7mm
                    Form1.PrintScale = 7
                Case "1cmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙10mm
                    Form1.PrintScale = 10
                Case "1.5cmレポート用紙"
                    Form1.PrintType = Form1.PrintTypeENum.レポート用紙15mm
                    Form1.PrintScale = 15
                Case "五線譜"
                    Form1.PrintType = Form1.PrintTypeENum.五線譜
                Case "400字原稿用紙"
                    Form1.PrintType = Form1.PrintTypeENum.原稿用紙400字
                    Dim UserCont3 As UserControl3 = Form1.SplitContainer1.Panel2.Controls("UserControl3")
                    UserCont3.NumUpDown_Gyo.Value = 20
                    Form1.GenkoGyo = 20
                    UserCont3.NumUpDown_Retsu.Value = 20
                    Form1.GenkoRetsu = 20
                Case "200字原稿用紙"
                    Form1.PrintType = Form1.PrintTypeENum.原稿用紙200字
                    Dim UserCont3 As UserControl3 = Form1.SplitContainer1.Panel2.Controls("UserControl3")
                    If Form1.PrintVectol = Form1.PrintVectolENum.横 Then
                        UserCont3.NumUpDown_Gyo.Value = 10
                        Form1.GenkoGyo = 10
                        UserCont3.NumUpDown_Retsu.Value = 20
                        Form1.GenkoRetsu = 20
                    Else
                        UserCont3.NumUpDown_Gyo.Value = 20
                        Form1.GenkoGyo = 20
                        UserCont3.NumUpDown_Retsu.Value = 10
                        Form1.GenkoRetsu = 10
                    End If
            End Select

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCListChange:" & ex.Message)
        End Try
    End Sub

    'タイトルテキストの変更
    Private Sub TextBox1_TextChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles TextBox1.TextChanged
        Try
            'タイトルテキストの反映
            Form1.Title = TextBox1.Text
            Form1.Label_TitlePreview.Text = TextBox1.Text

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCTitleTextEdit:" & ex.Message)
        End Try
    End Sub

    'プレビューの更新ボタンのクリック
    Private Sub Button4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button4.Click
        Try
            Dim UserCont2 As UserControl2 = Form1.SplitContainer1.Panel2.Controls("UserControl2")
            'プレビューの更新
            Form1.PrintPreviewControl1.InvalidatePreview()
            Form1.PrintPreviewControl1.Rows = Form1.PrintPages
            Panel_PenColor.BackColor = Form1.PenColor
            Form1.Panel1.BackColor = Form1.PenColor
            UserCont2.Panel_PenColor.BackColor = Form1.PenColor
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCRefresh:" & ex.Message)
        End Try
    End Sub

    '起動時の挙動
    Private Sub UserControl1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Try
            'プリンターの読み込み
            For Each PrinterName In Printing.PrinterSettings.InstalledPrinters
                ComboBox_Printer.Items.Add(PrinterName)
            Next
            'デフォルトプリンターを設定
            ComboBox_Printer.SelectedItem = Form1.PrintDocument1.PrinterSettings.PrinterName

            'サポートされている用紙サイズの取得
            ComBox_PrintSize.Items.Clear()
            '表示するプロパティをPaperNameとする
            ComBox_PrintSize.DisplayMember = "PaperName"
            For Each PaperSizeItem In Form1.PrintDocument1.PrinterSettings.PaperSizes
                'ComBox_PrintSizeに追加
                ComBox_PrintSize.Items.Add(PaperSizeItem)
            Next

            If ComBox_PrintSize.Items.Contains("A4") = True Then
                ComBox_PrintSize.SelectedItem = ("A4")
            Else
                ComBox_PrintSize.SelectedIndex = 0
            End If

            ComBox_PrintVectol.SelectedIndex = 0

            Form1.PrintDocument1.DefaultPageSettings.PaperSize = _
                Form1.PrintDocument1.PrinterSettings.PaperSizes(ComBox_PrintSize.SelectedIndex)

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                            Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                            MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCLoad:" & ex.Message)
        End Try
    End Sub

    '使用するプリンターを変更
    Private Sub ComboBox_Printer_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ComboBox_Printer.SelectedIndexChanged
        Form1.PrintDocument1.PrinterSettings.PrinterName = ComboBox_Printer.SelectedItem
        'ComboBox1の項目をクリアする
        ComBox_PrintSize.Items.Clear()

        '表示するプロパティをPaperNameとする
        ComBox_PrintSize.DisplayMember = "PaperName"

        'PaperSizeをComboBox1に追加していく
        Dim ps As System.Drawing.Printing.PaperSize
        For Each ps In Form1.PrintDocument1.PrinterSettings.PaperSizes
            ComBox_PrintSize.Items.Add(ps)
        Next ps
    End Sub
End Class
