﻿Imports System.Runtime.InteropServices
Public Class UserControl2

    ' Win32 APIのインポート
    <DllImport("USER32.DLL")> _
    Private Shared Function GetSystemMenu(ByVal hWnd As IntPtr, ByVal bRevert As Integer) As IntPtr
    End Function
    <DllImport("USER32.DLL")> _
    Private Shared Function RemoveMenu(ByVal hMenu As IntPtr, ByVal nPosition As Integer, ByVal wFlags As Integer) As Integer
    End Function

    ' ［閉じる］ボタンを無効化するための値
    Private Shared SC_CLOSE As Integer = &HF060
    Private Shared MF_BYCOMMAND As Integer = &H0

    ' コンストラクタ（初期化処理などを呼び出す）
    Public Sub New()
        MyBase.New()

        ' 初期化処理
        InitializeComponent()

        ' コントロールボックスの［閉じる］ボタンの無効化
        Dim hMenu As IntPtr = GetSystemMenu(Me.Handle, 0)
        RemoveMenu(hMenu, SC_CLOSE, MF_BYCOMMAND)

    End Sub

    Private Declare Function SendMessage Lib "User32.dll" Alias "SendMessageA" (ByVal hWnd As IntPtr, ByVal wMsg As Integer, ByVal wParam As Integer, ByVal lParam As Integer) As Long
    Private Declare Sub ReleaseCapture Lib "User32.dll" ()

    Const WM_NCLBUTTONDOWN = &HA1
    Const HTCAPTION = 2

    'Formダブルクリックで非表示にする
    Private Sub UserControl2_DoubleClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.DoubleClick
        Me.Visible = False
        Form1.線設定ウィンドウToolStripMenuItem.Checked = Me.Visible
    End Sub

    'Formをドラックで動かせるようにする
    Private Sub Form2_MouseMove(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseMove
        Try
            If e.Button = MouseButtons.Left Then
                Call ReleaseCapture()
                Call SendMessage(Me.Handle, WM_NCLBUTTONDOWN, HTCAPTION, 0&)
            End If
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCMouseMove:" & ex.Message)
        End Try

    End Sub

    '起動時の挙動
    Private Sub UserControl2_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ComboBox1.SelectedItem = "実線-Solid"
    End Sub

    '線種の変更
    Private Sub ComboBox1_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ComboBox1.SelectedIndexChanged
        Select Case ComboBox1.SelectedItem
            Case "実線-Solid"
                Form1.PenDashStyle = Drawing2D.DashStyle.Solid
            Case "破線-Dash"
                Form1.PenDashStyle = Drawing2D.DashStyle.Dash
            Case "点線-Dot"
                Form1.PenDashStyle = Drawing2D.DashStyle.Dot
            Case "破線,点-Dash,Dot"
                Form1.PenDashStyle = Drawing2D.DashStyle.DashDot
            Case "破線,点,点-Dash,Dot,Dot"
                Form1.PenDashStyle = Drawing2D.DashStyle.DashDotDot
        End Select
    End Sub

    '拡大ボタン
    Private Sub Button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button1.Click
        Try
            Form1.PrintPreviewControl1.Zoom += 0.1
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCZoomUp:" & ex.Message)
        End Try
    End Sub

    '縮小ボタン
    Private Sub Button2_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button2.Click
        Try
            If Form1.PrintPreviewControl1.Zoom > 0.2 Then
                Form1.PrintPreviewControl1.Zoom -= 0.1
            End If
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCZoomOut:" & ex.Message)
        End Try
    End Sub

    '線の色の変更ボタンクリック
    Private Sub Button3_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button3.Click
        Try
            'カラーダイアログの表示
            If ColorDialog1.ShowDialog <> Windows.Forms.DialogResult.Cancel Then
                Panel_PenColor.BackColor = ColorDialog1.Color
                Form1.PenColor = ColorDialog1.Color
                Form1.Panel1.BackColor = ColorDialog1.Color
            End If

        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCColorDialog:" & ex.Message)
        End Try
    End Sub

    '線の太さの変更
    Friend Sub NumUpDown_PenWid_ValueChanged(ByVal sender As System.Object, ByVal e As System.EventArgs)
        Try
            Dim UserCont1 As UserControl1 = Form1.SplitContainer1.Panel2.Controls("UserControl1")
            Form1.PenWidth = NumUpDown_PenWid.Value
            UserCont1.NumUpDown_PenWid.Value = NumUpDown_PenWid.Value
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCPenWidthChange:" & ex.Message)
        End Try
    End Sub

    'プレビューの更新ボタンクリック
    Private Sub Button4_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button4.Click
        Try
            Dim UserCont1 As UserControl1 = Form1.SplitContainer1.Panel2.Controls("UserControl1")
            'プレビューの更新
            Form1.PrintPreviewControl1.InvalidatePreview()
            Form1.PrintPreviewControl1.Rows = Form1.PrintPages
            'ペンの色の反映
            Panel_PenColor.BackColor = Form1.PenColor
            Form1.Panel1.BackColor = Form1.PenColor
            UserCont1.Panel_PenColor.BackColor = Form1.PenColor
        Catch ex As Exception
            MessageBox.Show("エラーが発生しました。" & vbNewLine & "Log.txtを添付して製作者にメールしてください。", _
                           Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error, _
                           MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
            Form1.WriteLog("UCRefresh:" & ex.Message)
        End Try
    End Sub
End Class